@@ -16,7 +16,7 @@ from dkist_processing_pac.tag import tag
 from dkist_processing_pac.M12 import ContinuumPolarization
 from dkist_processing_pac.data import S122
 from astropy.utils.exceptions import ErfaWarning
-from dkist_header_validator import spec122
+from dkist_fits_specifications import spec122
 
 warnings.filterwarnings('ignore', category=ErfaWarning)
 np.random.seed(42)
@@ -595,9 +595,9 @@ def SoCC_from_defaults(outputdir, CS_name, nummod=10, shape=(1, 1, 1), seed=42,
         ret0_r = np.random.random() * 0.015 + 0.02
     else:
         rng = np.random.default_rng(seed)
-        ret0_h = rng.uniform(params['ret0h'][wave_idx, :][0], params['ret0h'][wave_idx, :][2])
-        ret0_45 = rng.uniform(params['ret045'][wave_idx, :][0], params['ret045'][wave_idx, :][2])
-        ret0_r = rng.uniform(params['ret0r'][wave_idx, :][0], params['ret0r'][wave_idx, :][2])
+        ret0_h = legacy_uniform_generator(rng, params['ret0h'][wave_idx, :])
+        ret0_45 = legacy_uniform_generator(rng, params['ret045'][wave_idx, :])
+        ret0_r = legacy_uniform_generator(rng, params['ret0r'][wave_idx, :])
 
     if dret:
         # dret from assumption of 0.1 deg per deg C and a ~5 deg C heating over 15 min
@@ -916,6 +916,18 @@ def fill_spec122_header(header, inst_head):
 
     header[S122['InstrumentProgramID']] = 'gen_fake_data'
 
+def legacy_uniform_generator(rng, limits):
+    # Needed after numpy changed how uniform() works in 1.21.0
+    low = limits[0]
+    high = limits[-1]
+    scale = 1
+    if low > high:
+        low *= -1
+        high *= -1
+        scale *= -1
+
+    return scale * rng.uniform(low, high)
+
 #TODO: Move this to somewhere in the tests directory
 def make_testing_data():
     from ViSP_Pipeline.utils.gen_fake_data import ViSPDataSet
